# Changelog

## 0.1.0-alpha.1 (2024-07-14)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/OneBusAway/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update trip resource endpoint to use trip_id parameter ([505ac28](https://github.com/OneBusAway/python-sdk/commit/505ac28c233cdc34210863decd6bce6388d299b3))
* **api:** update via SDK Studio ([2fc0ce6](https://github.com/OneBusAway/python-sdk/commit/2fc0ce66e2d210b9d39a754dc412a1f78dde2425))
* **api:** update via SDK Studio ([58b87fc](https://github.com/OneBusAway/python-sdk/commit/58b87fc149b3a748b56a742b1312df4b7a288dc8))
* **api:** update via SDK Studio ([6fce548](https://github.com/OneBusAway/python-sdk/commit/6fce548afe8bd6c6cc7dfbee8cf2ae7eab4b17b6))
* **api:** update via SDK Studio ([7586440](https://github.com/OneBusAway/python-sdk/commit/75864402b21644233224847f316a3a4ed226eaa0))
* **api:** update via SDK Studio ([7a43139](https://github.com/OneBusAway/python-sdk/commit/7a431396cec7698593864f004ae7ae26bc48f407))
* **api:** update via SDK Studio ([9d44ad8](https://github.com/OneBusAway/python-sdk/commit/9d44ad8bdeeed5dd3565e7382f510a7c7b6c3425))
* **api:** update via SDK Studio ([92f3ad8](https://github.com/OneBusAway/python-sdk/commit/92f3ad86c78f8fcacb9db900bfcc6c5e1430d6d4))
* **api:** update via SDK Studio ([6155c59](https://github.com/OneBusAway/python-sdk/commit/6155c591599e910f3c1a6c27fa410f5f95d0efc1))
* **api:** update via SDK Studio ([c581bdb](https://github.com/OneBusAway/python-sdk/commit/c581bdb1782dba7b12e491968a2bd28aa01da6d3))
* **api:** update via SDK Studio ([fdb908c](https://github.com/OneBusAway/python-sdk/commit/fdb908c5d0ebf12f331be0c10e7d714ece909296))
* **api:** update via SDK Studio ([f1b0a5f](https://github.com/OneBusAway/python-sdk/commit/f1b0a5fb344842bda01724c0adb7043f8d83ba3e))
* **api:** update via SDK Studio ([85038fe](https://github.com/OneBusAway/python-sdk/commit/85038fe848673570ccdfd95b58be840c86e306bd))
* **api:** update via SDK Studio ([7da9927](https://github.com/OneBusAway/python-sdk/commit/7da992794551c82dfd53ec6f0a04ea745e4faf69))
* **api:** update via SDK Studio ([9521b6e](https://github.com/OneBusAway/python-sdk/commit/9521b6e7baeae134a86abb81a67967782fe8201e))
* **api:** update via SDK Studio ([b22b033](https://github.com/OneBusAway/python-sdk/commit/b22b0330bf195b5d23bbe56e8654cf74e8aa4b13))
* **api:** update via SDK Studio ([f8926c3](https://github.com/OneBusAway/python-sdk/commit/f8926c35c8fc29a84ceb87acf027d5442da9a090))
* **api:** update via SDK Studio ([0854942](https://github.com/OneBusAway/python-sdk/commit/08549428c36d5fa7e5e1db1b4095cd33e4228bff))
* **api:** update via SDK Studio ([7ddaf77](https://github.com/OneBusAway/python-sdk/commit/7ddaf77a336bbe1f058e80dd24b3cf10832a5c26))
* **api:** update via SDK Studio ([0809c44](https://github.com/OneBusAway/python-sdk/commit/0809c449d74a685fb8f3320c397e2ad9602ead5f))
* **api:** update via SDK Studio ([84da952](https://github.com/OneBusAway/python-sdk/commit/84da952b7e17b6ffe6044b562bb5a8b699e33971))
* **api:** update via SDK Studio ([db3e659](https://github.com/OneBusAway/python-sdk/commit/db3e659d827c0f782658a9ba5ea66fb1cacd057d))
* **api:** update via SDK Studio ([3beb328](https://github.com/OneBusAway/python-sdk/commit/3beb328f733f04252725ea46b2b67588a87aa0c4))
* **api:** update via SDK Studio ([1decfcf](https://github.com/OneBusAway/python-sdk/commit/1decfcf8e8b62d137c205bb68103130954d425e4))
* **api:** update via SDK Studio ([0ad9c15](https://github.com/OneBusAway/python-sdk/commit/0ad9c159c08945fa8fde230d133934c319af8a21))
* **api:** update via SDK Studio ([5ce8b85](https://github.com/OneBusAway/python-sdk/commit/5ce8b8522d5dff1435a433699d0eaa21177ed147))
* **api:** update via SDK Studio ([1b32372](https://github.com/OneBusAway/python-sdk/commit/1b32372e013eaf55acd3fa9fbeca12e9178a9063))
* **api:** update via SDK Studio ([ba50d73](https://github.com/OneBusAway/python-sdk/commit/ba50d73823485025802164f0a90bcda5d456f488))
* **api:** update via SDK Studio ([295f030](https://github.com/OneBusAway/python-sdk/commit/295f030e4584f83065c340fa907ebe18c1cca1d7))
* **api:** update via SDK Studio ([cfdc365](https://github.com/OneBusAway/python-sdk/commit/cfdc365c5711df9aea710ab40f394097be87283c))
* **api:** update via SDK Studio ([21115c3](https://github.com/OneBusAway/python-sdk/commit/21115c3b2134638118425bf9ec4d682403519c37))
* **api:** update via SDK Studio ([a80244d](https://github.com/OneBusAway/python-sdk/commit/a80244d027a606fdaf9df9049bb0941a2b29d1ff))
* **api:** update via SDK Studio ([f2a3418](https://github.com/OneBusAway/python-sdk/commit/f2a34180fb1bbd73adecae83503a4417cc2dd013))
* **api:** update via SDK Studio ([80a7f9e](https://github.com/OneBusAway/python-sdk/commit/80a7f9ede0b1ff0b4c2de938166a02136b0da2fe))
* **api:** update via SDK Studio ([b0bab66](https://github.com/OneBusAway/python-sdk/commit/b0bab660fe8a5ae248b554be13eea215957e5f44))
* **api:** update via SDK Studio ([fc88be6](https://github.com/OneBusAway/python-sdk/commit/fc88be647860cb3bf94d9799ed5fcd607dc2fc50))
* **api:** update via SDK Studio ([2d32178](https://github.com/OneBusAway/python-sdk/commit/2d321788f506d3ec776ed10a3dafe315ede012a2))
* **api:** update via SDK Studio ([4094e8a](https://github.com/OneBusAway/python-sdk/commit/4094e8acbf4ce995381c8aaf179ec03011d24a51))
* **api:** update via SDK Studio ([#1](https://github.com/OneBusAway/python-sdk/issues/1)) ([70824e7](https://github.com/OneBusAway/python-sdk/commit/70824e7f4278cba8fe045dd749d07577a21d2887))
* **Examples:** add agency endpoint ([c5f808a](https://github.com/OneBusAway/python-sdk/commit/c5f808a122fa2cf10651983f2e2070590fcda24e))
* **examples:** add example for testing api response ([98d1952](https://github.com/OneBusAway/python-sdk/commit/98d1952000347909010e81cd69363e943a4e33c8))


### Chores

* configure new SDK language ([23b3c89](https://github.com/OneBusAway/python-sdk/commit/23b3c890438d14ae70957aa275e9305dfaf49648))
* configure new SDK language ([9a9c0c6](https://github.com/OneBusAway/python-sdk/commit/9a9c0c65509d93e2221e41a9f408d326d6e48211))
* configure new SDK language ([63065e2](https://github.com/OneBusAway/python-sdk/commit/63065e26f68b57b0c74f457c926b38d7dcf600e7))
* configure new SDK language ([84b1ca6](https://github.com/OneBusAway/python-sdk/commit/84b1ca654f31302265219242964ab5700ef45148))
* configure new SDK language ([4b14ec2](https://github.com/OneBusAway/python-sdk/commit/4b14ec2cce6a83b529db5525636ffe14a0148916))
* configure new SDK language ([267eede](https://github.com/OneBusAway/python-sdk/commit/267eeded6e0de5d709d912ee5940b03660b1c806))
* format agency.py ([7776ddd](https://github.com/OneBusAway/python-sdk/commit/7776ddde7d1468f85d0e238537e87b6098a09e05))
* update SDK settings ([9bf975b](https://github.com/OneBusAway/python-sdk/commit/9bf975bd37829d53c730424fe4b3956a63d4d997))
* update SDK settings ([4886cd2](https://github.com/OneBusAway/python-sdk/commit/4886cd2bdf3a1703e907ee3a273a1be00d025ce6))


### Refactors

* **Api:** update agency resource endpoint to use agency_id parameter ([3760fc5](https://github.com/OneBusAway/python-sdk/commit/3760fc5d6969be25dc1228af68d927cae7c41863))
* **Api:** update API endpoint to use stop_id variable ([91625b8](https://github.com/OneBusAway/python-sdk/commit/91625b8671dd561c340e74c1d8a8ecdd8496fd7b))
* **api:** update arrival and departure resource endpoints to use stop_id parameter ([f267a9c](https://github.com/OneBusAway/python-sdk/commit/f267a9c20647ee6c2e3b5ab0a4d87862372fdb82))
* **api:** update tests endpoint to use api_key in param ([446cafd](https://github.com/OneBusAway/python-sdk/commit/446cafd532c627fb46c35887e4d2a32c16e5b726))
* **client:** update auth_headers method to return an empty dictionary ([8133b61](https://github.com/OneBusAway/python-sdk/commit/8133b61a7776964d965c14276dba02d6639149e2))
* **EndPoint:** update agency API endpoint to use agency_id variable ([6abcaa6](https://github.com/OneBusAway/python-sdk/commit/6abcaa66d066b5fb5fab379d5d26d12f4c63c806))
* **examples:** remove commented code and unused imports ([ffe2774](https://github.com/OneBusAway/python-sdk/commit/ffe27745b20e593f2770285d122bf53128b374a0))
* **route:** update route API endpoint to use route_id variable ([9857e55](https://github.com/OneBusAway/python-sdk/commit/9857e558f2f0ad355ca90af74978e23d48ba0948))
* **route:** update route resource endpoint to use route_id parameter ([643d71d](https://github.com/OneBusAway/python-sdk/commit/643d71da89b6e02275b032e6bd7a78b17066f06b))
* **test_transform:** fix base64 encoding issue ([fefa1fb](https://github.com/OneBusAway/python-sdk/commit/fefa1fb8d02dcc8c9b536f11cd3388b3ef3d8055))
* **test_transform:** fix base64 encoding issue ([9f35949](https://github.com/OneBusAway/python-sdk/commit/9f35949d97c184fb01e3df0bcd4a41bb43b3288d))
* **test_transform:** optimize base64 encoding ([1b2f58e](https://github.com/OneBusAway/python-sdk/commit/1b2f58e3ba3c76d13714e2b46b79ba2c7580ed29))
* **test_transform:** update base64 encoding ([b51acbe](https://github.com/OneBusAway/python-sdk/commit/b51acbee92d24aabb3c403b8a53a13a5e2e3c9ca))
* **test_transform:** update base64 encoding ([62ba4f2](https://github.com/OneBusAway/python-sdk/commit/62ba4f2ddcdb96a030d7b2ca7300b9ea3c35f504))
* **tests:** update base64 encoding in test_transform ([97a218e](https://github.com/OneBusAway/python-sdk/commit/97a218ee3b9ee49bb19fb38e6b6d07640a3cdc8a))
* **tests:** update sample_file.txt with newline character ([f0d7644](https://github.com/OneBusAway/python-sdk/commit/f0d76443778e46b4e3eb8f4862190c345da90c6c))
* **trip:** update trip API endpoint to use trip_id variable ([2602a05](https://github.com/OneBusAway/python-sdk/commit/2602a0537bd4af20306c5f755ec0fb17539153d3))
* update agency resource URL to use agency_id variable ([d600eb1](https://github.com/OneBusAway/python-sdk/commit/d600eb1146abd67cfda9a4658bf14274083c9568))
* Update agency resource URL to use agency_id variable ([2719d60](https://github.com/OneBusAway/python-sdk/commit/2719d600837503082d3255825b721d9f577c7824))
* Update API resource URLs to use agency_id variable ([b9c6499](https://github.com/OneBusAway/python-sdk/commit/b9c6499aaa3dc101b4a35966237aa9a161c7424a))
* update API resource URLs to use route_id variable ([b374991](https://github.com/OneBusAway/python-sdk/commit/b37499179c139ae5af128589506bc8f4fe4ad7f5))
* update API resource URLs to use route_id variable ([c80bdae](https://github.com/OneBusAway/python-sdk/commit/c80bdae0c9548d4deb5292911deac4ec45ce4cae))
* Update API resource URLs to use route_id variable ([8e8f38a](https://github.com/OneBusAway/python-sdk/commit/8e8f38a467fb4515ec66c2d525de4e9355415256))
* Update API resource URLs to use route_id variable ([b866e83](https://github.com/OneBusAway/python-sdk/commit/b866e832800bf04084bc9e2f025c8d1b326268f3))
* Update API resource URLs to use route_id variable ([3923494](https://github.com/OneBusAway/python-sdk/commit/39234949a5688648d6c81fbea5c7c59766188cbb))
* Update API resource URLs to use route_id variable ([0dbbc76](https://github.com/OneBusAway/python-sdk/commit/0dbbc76171b5a26cb80647f4adf9f8c6ceb003dc))
* update API resource URLs to use stop_id variable ([26cd3ed](https://github.com/OneBusAway/python-sdk/commit/26cd3edafe208a9552eaf9a5f0bee904d8e323cd))
* Update API resource URLs to use stop_id variable ([ea81ad9](https://github.com/OneBusAway/python-sdk/commit/ea81ad960d16f1bfc4d2b52103bd39b3ad98fbc6))
* Update API resource URLs to use stop_id variable ([9307bb7](https://github.com/OneBusAway/python-sdk/commit/9307bb78f5229c05fc04e7e172032be12fbfb79c))
* update API resource URLs to use trip_id variable ([0b100ed](https://github.com/OneBusAway/python-sdk/commit/0b100ed9b37db1b72fc5c0dc70e50c10c369e849))
* Update API resource URLs to use trip_id variable ([38687b9](https://github.com/OneBusAway/python-sdk/commit/38687b97f2d1ab434576b2e78c5241e70b04d617))
* Update API resource URLs to use trip_id variable ([c173e75](https://github.com/OneBusAway/python-sdk/commit/c173e751c71520683d8912718e121bd0d62db3ae))
* Update API resource URLs to use trip_id variable ([7c5fddb](https://github.com/OneBusAway/python-sdk/commit/7c5fddb1668b8049d358c18152b8687a82835110))
* update API resource URLs to use variable names ([a4f2bac](https://github.com/OneBusAway/python-sdk/commit/a4f2bacb0a5522c1ad5483ebe5b85390ac3aa728))
* Update API resource URLs to use variable names ([fc93fe5](https://github.com/OneBusAway/python-sdk/commit/fc93fe5d36f1d0a560a41e012a7beec615340996))
* Update API resource URLs to use variable names ([6d61f7f](https://github.com/OneBusAway/python-sdk/commit/6d61f7f605166cea6ea6655ccee9f829e33f7a8f))
* update auth_headers method to return an empty dictionary ([ab69500](https://github.com/OneBusAway/python-sdk/commit/ab695005be6ecca41165131a5f3e7167bde6b382))
* Update auth_headers method to return an empty dictionary ([2d7b81c](https://github.com/OneBusAway/python-sdk/commit/2d7b81ce9ca756909bfd3dc4a67d54cb19ec8aaa))
* Update auth_headers method to return an empty dictionary ([9d1f2b7](https://github.com/OneBusAway/python-sdk/commit/9d1f2b79d1a7b7bfb2a37937d607629400523fc4))
* Update main_sync function signature to include return type annotation ([653bb1a](https://github.com/OneBusAway/python-sdk/commit/653bb1a1d1108a1acd1a37b0fa7e6475cfede10a))
* update the test example ([6f6fa42](https://github.com/OneBusAway/python-sdk/commit/6f6fa42d6143e53ca56b6ca5b22f0d39b3c7b963))
